#!/usr/bin/python3

# Test opening a file with wrong extenstion.

from testCommon import run_app, bail

from dogtail.procedural import *

try:

	run_app(file='test-mime.bin')

	# Close xreader
	click('File', roleName='menu')
	click('Close', roleName='menu item')

except:
	bail()



#!/usr/bin/python3

# This test opens the View menu and test zoom features.

from testCommon import run_app, bail

from dogtail.procedural import *

try:
    run_app(file='test-links.pdf')

    # Zoom In
    focus.frame('test-links.pdf')
    click('View', roleName='menu')
    click('Zoom In', roleName='menu item')

    # Zoom Out
    click('View', roleName='menu')
    click('Zoom Out', roleName='menu item')

    # Close
    click('File', roleName='menu')
    click('Close', roleName='menu item')

except:
    bail()



#!/usr/bin/python3

# This test opens the Bookmarks menu.

from testCommon import run_app, bail

from dogtail.procedural import *

try:
    run_app(file='test-links.pdf')

    focus.frame('test-links.pdf')
    click('Bookmarks', roleName='menu')
    click('Add Bookmark', roleName='menu item')

    click('Bookmarks', roleName='menu')
    click('Page 1', roleName='menu item')

    # Close
    click('File', roleName='menu')
    click('Close', roleName='menu item')

except:
    bail()



#!/usr/bin/python3

# Test opening a password encrypted file and unlocking it.

from testCommon import run_app, bail

from dogtail.procedural import *

try:

	run_app(file='test-encrypt.pdf')

	# Try an incorrect password first
	focus.dialog('Enter password')
	type('wrong password')
	click('Unlock Document', roleName='push button')
	focus.dialog('Enter password')
	click('Cancel', roleName='push button')

	# Try again with the correct password
	focus.frame('test-encrypt.pdf — Password Required')
	click('Unlock Document', roleName='push button')
	type('Foo')
	focus.dialog('Enter password')
	click('Unlock Document', roleName='push button')

	# Close xreader
	focus.frame('test-encrypt.pdf — Dokument1')
	click('File', roleName='menu')
	click('Close', roleName='menu item')

except:
	bail()



#!/usr/bin/python3

# This test opens the Help menu and runs through the menu items.

from testCommon import run_app, bail

from dogtail.procedural import *

try:
    run_app()

    click('Help', roleName='menu')
    click('About', roleName='menu item')
    focus.dialog('About Xreader')
    click('License', roleName='toggle button')
    click('Close', roleName='push button')

    focus.frame('Recent Documents')
    click('Help', roleName='menu')
    click('Contents', roleName='menu item')

    keyCombo('<Control>w')

    focus.frame('Recent Documents')
    click('File', roleName='menu')
    click('Close', roleName='menu item')
except:
    bail()



#!/usr/bin/python3

import os
import subprocess

mimedir = os.path.join(os.environ['MESON_INSTALL_PREFIX'], 'share', 'mime')

if not os.environ.get('DESTDIR'):
    print('Updating mime database...')
    subprocess.call(['update-mime-database', mimedir])
